# Cepton SDK2
Cepton SDK version 2.x 

## Designed scopes
- Python3 only.
- Support python 3.7 or later due to the use of asyncio native coroutines
- Module itself is arch independent, but the FFI part loads from dynamic libraries

## Install
```bash
pip install cepton-sdk2
```

## Usage
```
import cepton_sdk2
```